==> 1cpp-2.0.3.5-src.zip: Source/SetOfHierarchy.h <==
// SetOfHierarchy.h: interface for the CSetOfHierarchy class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_SETOFHIERARCHY_H__B6166793_8666_47BA_8450_BAF6FC6D5FEA__INCLUDED_)
#define AFX_SETOFHIERARCHY_H__B6166793_8666_47BA_8450_BAF6FC6D5FEA__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#include "ComponentClass.h"
#include "OXY_Value.h"
#include <algorithm>
#include "MetaDataOfClasses.h"

/***********************************************************
*  
* CSetOfHierarchy *pHierarchy = CSetOfHierarchy::GetHierarchy(); //     
* pHierarchy->Init("    ","   Bin 1"); //  
* pHierarchy->ProcessDefines(); //     
************************************************************/


extern CBkEndUI * pBkEndUI;

#define DLLEXPORT __declspec( dllexport )

struct NameBindOfType {
    CString name;
    CString type;
    CString value;
    bool bIsVal;
    NameBindOfType (const CString& n, const CString& t, const CString& v = CString(""), bool bIs = false) : name(n), type(t), value(v), bIsVal(bIs) {}
};

//          1.
//       ,      .
//            .

class CSetOfHierarchy  
{
public:
	typedef CArray<CValue*, CValue*> ARRAY_VAL;

	
  CComponentClass* GetComponentClassCurExModule(CBLModule* pModWrapper = NULL);

  void ClearImplicitParams(CComponentClass *pComp);

  CBLContext* GetImplicitParamsList(CComponentClass *pComp, const char* lpcsNameMeth);

  bool GetImplicitParams(CComponentClass *pComp, CValue **ppPar, int nNumMeth);
  int SetImplicitParamOfInd(CComponentClass *pComp, const char* lpcsNameMeth, int nIndex, CValue* pVal);

  int GetNParams(const CComponentClass *pComp, int nNumMeth, int nNParams);

  //          
	void RestoreValParam(CComponentClass *pComponentClass, int nNumMeth, CValue **ppParam, ARRAY_VAL *arrValOfMeth);
  //  ,        
	bool SaveValParam(CComponentClass* pComponentClass, int nNumMeth, CValue** ppParam, ARRAY_VAL *arrValOfMeth);
  //            
	CString& GetNameOfFile(const CString& strNameOfMod);
  
  // 
	CSetOfHierarchy();
  // 
	~CSetOfHierarchy();

	// artbear   
	// 1 - , 0 - 
	bool VerifyRecursiveInBaseClasses(CString ClassName, CString BaseClassName, CString& sRecursiveHierarchy);

  //            
	bool InitInstanceComp(CComponentClass* pComponent);
  // 
  inline bool StillInitInstanceComp() {return pCreatedCompModule==NULL ? false : true;}
  void DeInitInstanceComp(CBLModule *pModWrapper);
// artbear -      OpenForm/  
  bool bIsOpenCompForm;
  inline void SetIsOpenCompForm(bool _bIsOpenCompForm) { bIsOpenCompForm = _bIsOpenCompForm; };
  inline bool IsOpenCompForm() { return bIsOpenCompForm; };
//end
	//     1    
	void RegistersContextClasses();
  
  //        
  bool CheckTypeOfParam(CComponentClass* pComponentClass,
					   int nNumMeth,
					   CValue** ppParamOfMeth, 
             CBLProcInfo* pProcInfo,
					   CValue* pRetValue = NULL);
  //         
  int GetParamDefValue(int iMethodNum, int iParamNum, CValue* pDefValue, const CComponentClass* pComponentClass);

  //     CSetOfHierarchy
  static CSetOfHierarchy* GetHierarchy();
  
  //     CSetOfHierarchy
  static void DeInitHierarchy();
  
  //      1
  CString pathBase1C;
  
  //         1
  CString pathBin1C;

  //  
  CMapStringToPtr m_SymbolOfPreprocessor;

  //            
  //      (...)
  struct InfoUnlimitsParams
  {
    CBLContext* cont_ValueList;
    vector<CValue*> vecPointOfPars;
    int         nNumAllParams;
    int         nNumExplicitParams;
  };
  
  static void RemoveNeedlessBlank(CString &str);
  
  typedef CArray<NameBindOfType*, NameBindOfType*> ARR_TYPE_NAME;
  
  bool TheClassIsDerive(const CString& derive, const CString& base) const;  
  bool IsObject(const CString& sClassName, const CString& sTryName) const;  

private:
	static void PrintError(const char* cstrError, const char* cstrFileName, int nNumLine);
  //      	
  
  CMetaDataOfClasses m_Meta;
  	
  //CMapPtrToPtr   m_BindInstaceValueList;  
  //           
  //CArray<COXY_Value*, COXY_Value*> m_ParamValOfMeth;
  
  //    CSetOfHierarchy
  static CSetOfHierarchy* pGlobalHierarchy;

  //      
  //          
  CComponentClass* pCreatedCompModule;

  //         
  //  -   ,  -    CComponentClass
  CMapPtrToPtr m_MapOfModulesAndComp;
   
  //      include   
  CMapStringToString m_LoadedIncludeFiles;
  
  //      ,      .
  //             = ""
  vector<int> m_VecNumOfParForPassCheckType;

public:  		
	void ReadDefinesAndCompile(CString &str, CString &strNameFile);
	
  void Init(const char* IBDir = NULL, const char* BinDir = NULL);

	static void MakeFullFileName(CString* name, LPCSTR sSecondPath = NULL);
	bool IsMethExist(const char* pNameClass, const char* pNameMeth) const;
	ARR_TYPE_NAME* GetInfoParamMeth(const char *pstrNameClass, const char *pstrNameMeth) const;
	CString GetNamesMethOfClass(const char* pNameClass, const char* sep = ",") const;
  //         strNameCl,  sep
	CString GetBaseClasses(const char* strNameCl, const char* sep = ",") const;
	void LoadListNameOfIncludeFiles(CStringArray& arr);
	CString GetAllAliasAndPath(const char* sep = "\r\n") const;
	CString GetAllClassesNames(const char* sep = "\r\n") const;
	CString GetDefSymbolOfPreproc(const char* sep = "\r\n") const;
	CString GetLoadIncludeFiles(const char* sep = "\r\n") const;
	int GetCountMethods() const;
	int GetCountClasses() const;
	bool IsClassExist(const char*);
	void InitParamDefsClass(CParamDefs * par, CString strClass);
	bool isMethHaveParVal(CString strName);
	bool ThisIsUnLimMethod(CString strName);
	int m_CountParametersInCallMethod;
  
  //    
  void ProcessDefines();

	CString GetPathFromAlias(CString strAls);
  //        :
  CString m_strClassAndMethImplicit;
  CString m_strClassAndMethCurrent;
  
  CString GetClassNameFromDefinition(const CString& ClassName) const;
};

#endif // !defined(AFX_SETOFHIERARCHY_H__B6166793_8666_47BA_8450_BAF6FC6D5FEA__INCLUDED_)

==> 1cpp-2.5.0.1-src.zip: Source/SetOfHierarchy.h <==
// SetOfHierarchy.h: interface for the CSetOfHierarchy class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_SETOFHIERARCHY_H__B6166793_8666_47BA_8450_BAF6FC6D5FEA__INCLUDED_)
#define AFX_SETOFHIERARCHY_H__B6166793_8666_47BA_8450_BAF6FC6D5FEA__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#include "ComponentClass.h"
#include "Preprocessor.h"
#include "OXY_Value.h"
#include <algorithm>
#include "MetaDataOfClasses.h"

/***********************************************************
*  
* CSetOfHierarchy *pHierarchy = CSetOfHierarchy::GetHierarchy(); //     
* pHierarchy->Init("    ","   Bin 1"); //  
* pHierarchy->ProcessDefines(); //     
************************************************************/


extern CBkEndUI * pBkEndUI;

#define DLLEXPORT __declspec( dllexport )

struct NameBindOfType {
    CString name;
    CString type;
    CString value;
    bool bIsVal;
    NameBindOfType (const CString& n, const CString& t, const CString& v = CString(""), bool bIs = false) : name(n), type(t), value(v), bIsVal(bIs) {}
};

//          1.
//       ,      .
//            .

class CSetOfHierarchy  
{
public:
  
	//            
	CString& GetNameOfFile(const CString& strNameOfMod);
  
  // 
	CSetOfHierarchy();
  // 
	~CSetOfHierarchy();

	// artbear   
	// 1 - , 0 - 
	bool VerifyRecursiveInBaseClasses(CString ClassName, CString BaseClassName, CString& sRecursiveHierarchy);

	// artbear -      OpenForm/  
  bool bIsOpenCompForm;
  inline void SetIsOpenCompForm(bool _bIsOpenCompForm) { bIsOpenCompForm = _bIsOpenCompForm; };
  inline bool IsOpenCompForm() { return bIsOpenCompForm; };

  //     1    
	void RegistersContextClasses();
  
  //        
  bool CheckTypeOfParam(CComponentClass* pComponentClass,
					   int nNumMeth,
					   CValue** ppParamOfMeth, 
             CBLProcInfo* pProcInfo,
					   CValue* pRetValue = NULL);
  //         
  int GetParamDefValue(int iMethodNum, int iParamNum, CValue* pDefValue, const CComponentClass* pComponentClass);

  //     CSetOfHierarchy
  static CSetOfHierarchy* GetHierarchy();
  
  //     CSetOfHierarchy
  static void DeInitHierarchy();
  
  //      1
  CString pathBase1C;
  
  //         1
  CString pathBin1C;

  //  
  CMapStringToPtr m_SymbolOfPreprocessor;
  
  static void RemoveNeedlessBlank(CString &str);
  
  typedef CArray<NameBindOfType*, NameBindOfType*> ARR_TYPE_NAME;
  
  bool TheClassIsDerive(const CString& derive, const CString& base) const;  
  bool IsObject(const CString& sClassName, const CString& sTryName) const;  

private:
	static void PrintError(const char* cstrError, const char* cstrFileName, int nNumLine);
  //      	
  
  CMetaDataOfClasses m_Meta;
  	
  //           
  //CArray<COXY_Value*, COXY_Value*> m_ParamValOfMeth;
  
  //    CSetOfHierarchy
  static CSetOfHierarchy* pGlobalHierarchy;

  //      include   
  CMapStringToString m_LoadedIncludeFiles;
  
  //      ,      .
  //             = ""
  vector<int> m_VecNumOfParForPassCheckType;

public:  		
	void ReadDefinesAndCompile(CString &str, const CString &strNameFile);
	
  void Init(const char* IBDir = NULL, const char* BinDir = NULL);

	static void MakeFullFileName(CString* name, LPCSTR sSecondPath = NULL);
	bool IsMethExist(const char* pNameClass, const char* pNameMeth) const;
	ARR_TYPE_NAME* GetInfoParamMeth(const char *pstrNameClass, const char *pstrNameMeth) const;
	CString GetNamesMethOfClass(const char* pNameClass, const char* sep = ",") const;
  //         strNameCl,  sep
	CString GetBaseClasses(const char* strNameCl, const char* sep = ",") const;
	void LoadListNameOfIncludeFiles(CStringArray& arr);
	CString GetAllAliasAndPath(const char* sep = "\r\n") const;
	CString GetAllClassesNames(const char* sep = "\r\n") const;
	CString GetDefSymbolOfPreproc(const char* sep = "\r\n") const;
	CString GetLoadIncludeFiles(const char* sep = "\r\n") const;
	int GetCountMethods() const;
	int GetCountClasses() const;
	bool IsClassExist(const char*);
	void InitParamDefsClass(CParamDefs * par, CString strClass);
	bool isMethHaveParVal(CString strName);
	bool ThisIsUnLimMethod(CString strName);
  
  //    
  void ProcessDefines();

	CString GetPathFromAlias(CString strAls);
  //        :

  CString GetClassNameFromDefinition(const CString& ClassName) const;

  CMetaDataOfClasses& GetMetaDataOfClasses(void)
  { return m_Meta; }

  void LoadNewClasssesDefine(CString &str, const CString &strNameFile);

};

#endif // !defined(AFX_SETOFHIERARCHY_H__B6166793_8666_47BA_8450_BAF6FC6D5FEA__INCLUDED_)
